#############################################################################
##
## Copyright (C) 2020 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of Qt for Python.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 3 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL3 included in the
## packaging of this file. Please review the following information to
## ensure the GNU Lesser General Public License version 3 requirements
## will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 2.0 or (at your option) the GNU General
## Public license version 3 or any later version approved by the KDE Free
## Qt Foundation. The licenses are as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-2.0.html and
## https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################
from __future__ import annotations

"""
This file contains the exact signatures for all functions in module
PySide2.QtMultimediaWidgets, except for defaults which are replaced by "...".
"""

# Module PySide2.QtMultimediaWidgets
import PySide2
try:
    import typing
except ImportError:
    from PySide2.support.signature import typing
from PySide2.support.signature.mapping import (
    Virtual, Missing, Invalid, Default, Instance)

from shiboken2 import Shiboken

import PySide2.QtCore
import PySide2.QtWidgets
import PySide2.QtMultimedia
import PySide2.QtMultimediaWidgets


class QCameraViewfinder(PySide2.QtMultimediaWidgets.QVideoWidget):

    def __init__(self, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ...) -> None: ...


class QGraphicsVideoItem(PySide2.QtWidgets.QGraphicsObject, PySide2.QtMultimedia.QMediaBindableInterface):

    def __init__(self, parent: typing.Optional[PySide2.QtWidgets.QGraphicsItem] = ...) -> None: ...


class QVideoWidget(PySide2.QtWidgets.QWidget, PySide2.QtMultimedia.QMediaBindableInterface):

    def __init__(self, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ...) -> None: ...


class QVideoWidgetControl(PySide2.QtMultimedia.QMediaControl):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...


# eof



#############################################################################
##
## Copyright (C) 2020 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of Qt for Python.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 3 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL3 included in the
## packaging of this file. Please review the following information to
## ensure the GNU Lesser General Public License version 3 requirements
## will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 2.0 or (at your option) the GNU General
## Public license version 3 or any later version approved by the KDE Free
## Qt Foundation. The licenses are as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-2.0.html and
## https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################
from __future__ import annotations

"""
This file contains the exact signatures for all functions in module
PySide2.QtOpenGL, except for defaults which are replaced by "...".
"""

# Module PySide2.QtOpenGL
import PySide2
try:
    import typing
except ImportError:
    from PySide2.support.signature import typing
from PySide2.support.signature.mapping import (
    Virtual, Missing, Invalid, Default, Instance)

from shiboken2 import Shiboken

import PySide2.QtCore
import PySide2.QtGui
import PySide2.QtWidgets
import PySide2.QtOpenGL


class QGL(Shiboken.Object):
    DoubleBuffer             : QGL.FormatOption = ... # 0x1
    DepthBuffer              : QGL.FormatOption = ... # 0x2
    Rgba                     : QGL.FormatOption = ... # 0x4
    AlphaChannel             : QGL.FormatOption = ... # 0x8
    AccumBuffer              : QGL.FormatOption = ... # 0x10
    StencilBuffer            : QGL.FormatOption = ... # 0x20
    StereoBuffers            : QGL.FormatOption = ... # 0x40
    DirectRendering          : QGL.FormatOption = ... # 0x80
    HasOverlay               : QGL.FormatOption = ... # 0x100
    SampleBuffers            : QGL.FormatOption = ... # 0x200
    DeprecatedFunctions      : QGL.FormatOption = ... # 0x400
    SingleBuffer             : QGL.FormatOption = ... # 0x10000
    NoDepthBuffer            : QGL.FormatOption = ... # 0x20000
    ColorIndex               : QGL.FormatOption = ... # 0x40000
    NoAlphaChannel           : QGL.FormatOption = ... # 0x80000
    NoAccumBuffer            : QGL.FormatOption = ... # 0x100000
    NoStencilBuffer          : QGL.FormatOption = ... # 0x200000
    NoStereoBuffers          : QGL.FormatOption = ... # 0x400000
    IndirectRendering        : QGL.FormatOption = ... # 0x800000
    NoOverlay                : QGL.FormatOption = ... # 0x1000000
    NoSampleBuffers          : QGL.FormatOption = ... # 0x2000000
    NoDeprecatedFunctions    : QGL.FormatOption = ... # 0x4000000

    class FormatOption(Shiboken.Enum):
        DoubleBuffer             : QGL.FormatOption = ... # 0x1
        DepthBuffer              : QGL.FormatOption = ... # 0x2
        Rgba                     : QGL.FormatOption = ... # 0x4
        AlphaChannel             : QGL.FormatOption = ... # 0x8
        AccumBuffer              : QGL.FormatOption = ... # 0x10
        StencilBuffer            : QGL.FormatOption = ... # 0x20
        StereoBuffers            : QGL.FormatOption = ... # 0x40
        DirectRendering          : QGL.FormatOption = ... # 0x80
        HasOverlay               : QGL.FormatOption = ... # 0x100
        SampleBuffers            : QGL.FormatOption = ... # 0x200
        DeprecatedFunctions      : QGL.FormatOption = ... # 0x400
        SingleBuffer             : QGL.FormatOption = ... # 0x10000
        NoDepthBuffer            : QGL.FormatOption = ... # 0x20000
        ColorIndex               : QGL.FormatOption = ... # 0x40000
        NoAlphaChannel           : QGL.FormatOption = ... # 0x80000
        NoAccumBuffer            : QGL.FormatOption = ... # 0x100000
        NoStencilBuffer          : QGL.FormatOption = ... # 0x200000
        NoStereoBuffers          : QGL.FormatOption = ... # 0x400000
        IndirectRendering        : QGL.FormatOption = ... # 0x800000
        NoOverlay                : QGL.FormatOption = ... # 0x1000000
        NoSampleBuffers          : QGL.FormatOption = ... # 0x2000000
        NoDeprecatedFunctions    : QGL.FormatOption = ... # 0x4000000

    class FormatOptions(object): ...


class QGLBuffer(Shiboken.Object):
    ReadOnly                 : QGLBuffer.Access = ... # 0x88b8
    WriteOnly                : QGLBuffer.Access = ... # 0x88b9
    ReadWrite                : QGLBuffer.Access = ... # 0x88ba
    VertexBuffer             : QGLBuffer.Type = ... # 0x8892
    IndexBuffer              : QGLBuffer.Type = ... # 0x8893
    PixelPackBuffer          : QGLBuffer.Type = ... # 0x88eb
    PixelUnpackBuffer        : QGLBuffer.Type = ... # 0x88ec
    StreamDraw               : QGLBuffer.UsagePattern = ... # 0x88e0
    StreamRead               : QGLBuffer.UsagePattern = ... # 0x88e1
    StreamCopy               : QGLBuffer.UsagePattern = ... # 0x88e2
    StaticDraw               : QGLBuffer.UsagePattern = ... # 0x88e4
    StaticRead               : QGLBuffer.UsagePattern = ... # 0x88e5
    StaticCopy               : QGLBuffer.UsagePattern = ... # 0x88e6
    DynamicDraw              : QGLBuffer.UsagePattern = ... # 0x88e8
    DynamicRead              : QGLBuffer.UsagePattern = ... # 0x88e9
    DynamicCopy              : QGLBuffer.UsagePattern = ... # 0x88ea

    class Access(Shiboken.Enum):
        ReadOnly                 : QGLBuffer.Access = ... # 0x88b8
        WriteOnly                : QGLBuffer.Access = ... # 0x88b9
        ReadWrite                : QGLBuffer.Access = ... # 0x88ba

    class Type(Shiboken.Enum):
        VertexBuffer             : QGLBuffer.Type = ... # 0x8892
        IndexBuffer              : QGLBuffer.Type = ... # 0x8893
        PixelPackBuffer          : QGLBuffer.Type = ... # 0x88eb
        PixelUnpackBuffer        : QGLBuffer.Type = ... # 0x88ec

    class UsagePattern(Shiboken.Enum):
        StreamDraw               : QGLBuffer.UsagePattern = ... # 0x88e0
        StreamRead               : QGLBuffer.UsagePattern = ... # 0x88e1
        StreamCopy               : QGLBuffer.UsagePattern = ... # 0x88e2
        StaticDraw               : QGLBuffer.UsagePattern = ... # 0x88e4
        StaticRead               : QGLBuffer.UsagePattern = ... # 0x88e5
        StaticCopy               : QGLBuffer.UsagePattern = ... # 0x88e6
        DynamicDraw              : QGLBuffer.UsagePattern = ... # 0x88e8
        DynamicRead              : QGLBuffer.UsagePattern = ... # 0x88e9
        DynamicCopy              : QGLBuffer.UsagePattern = ... # 0x88ea

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtOpenGL.QGLBuffer) -> None: ...
    @typing.overload
    def __init__(self, type: PySide2.QtOpenGL.QGLBuffer.Type) -> None: ...


class QGLColormap(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide2.QtOpenGL.QGLColormap) -> None: ...


class QGLContext(Shiboken.Object):
    NoBindOption             : QGLContext.BindOption = ... # 0x0
    InvertedYBindOption      : QGLContext.BindOption = ... # 0x1
    MipmapBindOption         : QGLContext.BindOption = ... # 0x2
    PremultipliedAlphaBindOption: QGLContext.BindOption = ... # 0x4
    LinearFilteringBindOption: QGLContext.BindOption = ... # 0x8
    DefaultBindOption        : QGLContext.BindOption = ... # 0xb
    MemoryManagedBindOption  : QGLContext.BindOption = ... # 0x10
    InternalBindOption       : QGLContext.BindOption = ... # 0x14
    CanFlipNativePixmapBindOption: QGLContext.BindOption = ... # 0x20
    TemporarilyCachedBindOption: QGLContext.BindOption = ... # 0x40

    class BindOption(Shiboken.Enum):
        NoBindOption             : QGLContext.BindOption = ... # 0x0
        InvertedYBindOption      : QGLContext.BindOption = ... # 0x1
        MipmapBindOption         : QGLContext.BindOption = ... # 0x2
        PremultipliedAlphaBindOption: QGLContext.BindOption = ... # 0x4
        LinearFilteringBindOption: QGLContext.BindOption = ... # 0x8
        DefaultBindOption        : QGLContext.BindOption = ... # 0xb
        MemoryManagedBindOption  : QGLContext.BindOption = ... # 0x10
        InternalBindOption       : QGLContext.BindOption = ... # 0x14
        CanFlipNativePixmapBindOption: QGLContext.BindOption = ... # 0x20
        TemporarilyCachedBindOption: QGLContext.BindOption = ... # 0x40

    class BindOptions(object): ...

    def __init__(self, format: PySide2.QtOpenGL.QGLFormat) -> None: ...


class QGLFormat(Shiboken.Object):
    NoProfile                : QGLFormat.OpenGLContextProfile = ... # 0x0
    CoreProfile              : QGLFormat.OpenGLContextProfile = ... # 0x1
    CompatibilityProfile     : QGLFormat.OpenGLContextProfile = ... # 0x2
    OpenGL_Version_None      : QGLFormat.OpenGLVersionFlag = ... # 0x0
    OpenGL_Version_1_1       : QGLFormat.OpenGLVersionFlag = ... # 0x1
    OpenGL_Version_1_2       : QGLFormat.OpenGLVersionFlag = ... # 0x2
    OpenGL_Version_1_3       : QGLFormat.OpenGLVersionFlag = ... # 0x4
    OpenGL_Version_1_4       : QGLFormat.OpenGLVersionFlag = ... # 0x8
    OpenGL_Version_1_5       : QGLFormat.OpenGLVersionFlag = ... # 0x10
    OpenGL_Version_2_0       : QGLFormat.OpenGLVersionFlag = ... # 0x20
    OpenGL_Version_2_1       : QGLFormat.OpenGLVersionFlag = ... # 0x40
    OpenGL_ES_Common_Version_1_0: QGLFormat.OpenGLVersionFlag = ... # 0x80
    OpenGL_ES_CommonLite_Version_1_0: QGLFormat.OpenGLVersionFlag = ... # 0x100
    OpenGL_ES_Common_Version_1_1: QGLFormat.OpenGLVersionFlag = ... # 0x200
    OpenGL_ES_CommonLite_Version_1_1: QGLFormat.OpenGLVersionFlag = ... # 0x400
    OpenGL_ES_Version_2_0    : QGLFormat.OpenGLVersionFlag = ... # 0x800
    OpenGL_Version_3_0       : QGLFormat.OpenGLVersionFlag = ... # 0x1000
    OpenGL_Version_3_1       : QGLFormat.OpenGLVersionFlag = ... # 0x2000
    OpenGL_Version_3_2       : QGLFormat.OpenGLVersionFlag = ... # 0x4000
    OpenGL_Version_3_3       : QGLFormat.OpenGLVersionFlag = ... # 0x8000
    OpenGL_Version_4_0       : QGLFormat.OpenGLVersionFlag = ... # 0x10000
    OpenGL_Version_4_1       : QGLFormat.OpenGLVersionFlag = ... # 0x20000
    OpenGL_Version_4_2       : QGLFormat.OpenGLVersionFlag = ... # 0x40000
    OpenGL_Version_4_3       : QGLFormat.OpenGLVersionFlag = ... # 0x80000

    class OpenGLContextProfile(Shiboken.Enum):
        NoProfile                : QGLFormat.OpenGLContextProfile = ... # 0x0
        CoreProfile              : QGLFormat.OpenGLContextProfile = ... # 0x1
        CompatibilityProfile     : QGLFormat.OpenGLContextProfile = ... # 0x2

    class OpenGLVersionFlag(Shiboken.Enum):
        OpenGL_Version_None      : QGLFormat.OpenGLVersionFlag = ... # 0x0
        OpenGL_Version_1_1       : QGLFormat.OpenGLVersionFlag = ... # 0x1
        OpenGL_Version_1_2       : QGLFormat.OpenGLVersionFlag = ... # 0x2
        OpenGL_Version_1_3       : QGLFormat.OpenGLVersionFlag = ... # 0x4
        OpenGL_Version_1_4       : QGLFormat.OpenGLVersionFlag = ... # 0x8
        OpenGL_Version_1_5       : QGLFormat.OpenGLVersionFlag = ... # 0x10
        OpenGL_Version_2_0       : QGLFormat.OpenGLVersionFlag = ... # 0x20
        OpenGL_Version_2_1       : QGLFormat.OpenGLVersionFlag = ... # 0x40
        OpenGL_ES_Common_Version_1_0: QGLFormat.OpenGLVersionFlag = ... # 0x80
        OpenGL_ES_CommonLite_Version_1_0: QGLFormat.OpenGLVersionFlag = ... # 0x100
        OpenGL_ES_Common_Version_1_1: QGLFormat.OpenGLVersionFlag = ... # 0x200
        OpenGL_ES_CommonLite_Version_1_1: QGLFormat.OpenGLVersionFlag = ... # 0x400
        OpenGL_ES_Version_2_0    : QGLFormat.OpenGLVersionFlag = ... # 0x800
        OpenGL_Version_3_0       : QGLFormat.OpenGLVersionFlag = ... # 0x1000
        OpenGL_Version_3_1       : QGLFormat.OpenGLVersionFlag = ... # 0x2000
        OpenGL_Version_3_2       : QGLFormat.OpenGLVersionFlag = ... # 0x4000
        OpenGL_Version_3_3       : QGLFormat.OpenGLVersionFlag = ... # 0x8000
        OpenGL_Version_4_0       : QGLFormat.OpenGLVersionFlag = ... # 0x10000
        OpenGL_Version_4_1       : QGLFormat.OpenGLVersionFlag = ... # 0x20000
        OpenGL_Version_4_2       : QGLFormat.OpenGLVersionFlag = ... # 0x40000
        OpenGL_Version_4_3       : QGLFormat.OpenGLVersionFlag = ... # 0x80000

    class OpenGLVersionFlags(object): ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, options: PySide2.QtOpenGL.QGL.FormatOptions, plane: int = ...) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtOpenGL.QGLFormat) -> None: ...


class QGLFramebufferObject(PySide2.QtGui.QPaintDevice):
    NoAttachment             : QGLFramebufferObject.Attachment = ... # 0x0
    CombinedDepthStencil     : QGLFramebufferObject.Attachment = ... # 0x1
    Depth                    : QGLFramebufferObject.Attachment = ... # 0x2

    class Attachment(Shiboken.Enum):
        NoAttachment             : QGLFramebufferObject.Attachment = ... # 0x0
        CombinedDepthStencil     : QGLFramebufferObject.Attachment = ... # 0x1
        Depth                    : QGLFramebufferObject.Attachment = ... # 0x2

    @typing.overload
    def __init__(self, size: PySide2.QtCore.QSize, attachment: PySide2.QtOpenGL.QGLFramebufferObject.Attachment, target: int = ..., internal_format: int = ...) -> None: ...
    @typing.overload
    def __init__(self, size: PySide2.QtCore.QSize, format: PySide2.QtOpenGL.QGLFramebufferObjectFormat) -> None: ...
    @typing.overload
    def __init__(self, size: PySide2.QtCore.QSize, target: int = ...) -> None: ...
    @typing.overload
    def __init__(self, width: int, height: int, attachment: PySide2.QtOpenGL.QGLFramebufferObject.Attachment, target: int = ..., internal_format: int = ...) -> None: ...
    @typing.overload
    def __init__(self, width: int, height: int, format: PySide2.QtOpenGL.QGLFramebufferObjectFormat) -> None: ...
    @typing.overload
    def __init__(self, width: int, height: int, target: int = ...) -> None: ...


class QGLFramebufferObjectFormat(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtOpenGL.QGLFramebufferObjectFormat) -> None: ...


class QGLPixelBuffer(PySide2.QtGui.QPaintDevice):

    @typing.overload
    def __init__(self, size: PySide2.QtCore.QSize, format: PySide2.QtOpenGL.QGLFormat = ..., shareWidget: typing.Optional[PySide2.QtOpenGL.QGLWidget] = ...) -> None: ...
    @typing.overload
    def __init__(self, width: int, height: int, format: PySide2.QtOpenGL.QGLFormat = ..., shareWidget: typing.Optional[PySide2.QtOpenGL.QGLWidget] = ...) -> None: ...


class QGLShader(PySide2.QtCore.QObject):
    Vertex                   : QGLShader.ShaderTypeBit = ... # 0x1
    Fragment                 : QGLShader.ShaderTypeBit = ... # 0x2
    Geometry                 : QGLShader.ShaderTypeBit = ... # 0x4

    class ShaderType(object): ...

    class ShaderTypeBit(Shiboken.Enum):
        Vertex                   : QGLShader.ShaderTypeBit = ... # 0x1
        Fragment                 : QGLShader.ShaderTypeBit = ... # 0x2
        Geometry                 : QGLShader.ShaderTypeBit = ... # 0x4

    @typing.overload
    def __init__(self, type: PySide2.QtOpenGL.QGLShader.ShaderType, context: PySide2.QtOpenGL.QGLContext, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...
    @typing.overload
    def __init__(self, type: PySide2.QtOpenGL.QGLShader.ShaderType, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...


class QGLShaderProgram(PySide2.QtCore.QObject):

    @typing.overload
    def __init__(self, context: PySide2.QtOpenGL.QGLContext, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...


class QGLWidget(PySide2.QtWidgets.QWidget):

    @typing.overload
    def __init__(self, context: PySide2.QtOpenGL.QGLContext, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ..., shareWidget: typing.Optional[PySide2.QtOpenGL.QGLWidget] = ..., f: PySide2.QtCore.Qt.WindowFlags = ...) -> None: ...
    @typing.overload
    def __init__(self, format: PySide2.QtOpenGL.QGLFormat, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ..., shareWidget: typing.Optional[PySide2.QtOpenGL.QGLWidget] = ..., f: PySide2.QtCore.Qt.WindowFlags = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ..., shareWidget: typing.Optional[PySide2.QtOpenGL.QGLWidget] = ..., f: PySide2.QtCore.Qt.WindowFlags = ...) -> None: ...


# eof



#############################################################################
##
## Copyright (C) 2020 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of Qt for Python.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 3 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL3 included in the
## packaging of this file. Please review the following information to
## ensure the GNU Lesser General Public License version 3 requirements
## will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 2.0 or (at your option) the GNU General
## Public license version 3 or any later version approved by the KDE Free
## Qt Foundation. The licenses are as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-2.0.html and
## https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################
from __future__ import annotations

"""
This file contains the exact signatures for all functions in module
PySide2.QtX11Extras, except for defaults which are replaced by "...".
"""

# Module PySide2.QtX11Extras
import PySide2
try:
    import typing
except ImportError:
    from PySide2.support.signature import typing
from PySide2.support.signature.mapping import (
    Virtual, Missing, Invalid, Default, Instance)

from shiboken2 import Shiboken

import PySide2.QtX11Extras


class QX11Info(Shiboken.Object):
    PeekDefault              : QX11Info.PeekOption = ... # 0x0
    PeekFromCachedIndex      : QX11Info.PeekOption = ... # 0x1

    class PeekOption(Shiboken.Enum):
        PeekDefault              : QX11Info.PeekOption = ... # 0x0
        PeekFromCachedIndex      : QX11Info.PeekOption = ... # 0x1

    class PeekOptions(object): ...

# eof



"""
Makes it possible to do the compiled analysis in a subprocess. This has two
goals:

1. Making it safer - Segfaults and RuntimeErrors as well as stdout/stderr can
   be ignored and dealt with.
2. Make it possible to handle different Python versions as well as virtualenvs.

The architecture here is briefly:
 - For each Jedi `Environment` there is a corresponding subprocess which
   operates within the target environment. If the subprocess dies it is replaced
   at this level.
 - `CompiledSubprocess` manages exactly one subprocess and handles communication
   from the parent side.
 - `Listener` runs within the subprocess, processing each request and yielding
   results.
 - `InterpreterEnvironment` provides an API which matches that of `Environment`,
   but runs functionality inline rather than within a subprocess. It is thus
   used both directly in places where a subprocess is unnecessary and/or
   undesirable and also within subprocesses themselves.
 - `InferenceStateSubprocess` (or `InferenceStateSameProcess`) provide high
   level access to functionality within the subprocess from within the parent.
   Each `InterpreterState` has an instance of one of these, provided by its
   environment.
"""

import collections
import os
import sys
import queue
import subprocess
import traceback
import weakref
from functools import partial
from threading import Thread
from typing import Dict, TYPE_CHECKING

from jedi._compatibility import pickle_dump, pickle_load
from jedi import debug
from jedi.cache import memoize_method
from jedi.inference.compiled.subprocess import functions
from jedi.inference.compiled.access import DirectObjectAccess, AccessPath, \
    SignatureParam
from jedi.api.exceptions import InternalError

if TYPE_CHECKING:
    from jedi.inference import InferenceState


_MAIN_PATH = os.path.join(os.path.dirname(__file__), '__main__.py')
PICKLE_PROTOCOL = 4


def _GeneralizedPopen(*args, **kwargs):
    if os.name == 'nt':
        try:
            # Was introduced in Python 3.7.
            CREATE_NO_WINDOW = subprocess.CREATE_NO_WINDOW
        except AttributeError:
            CREATE_NO_WINDOW = 0x08000000
        kwargs['creationflags'] = CREATE_NO_WINDOW
    # The child process doesn't need file descriptors except 0, 1, 2.
    # This is unix only.
    kwargs['close_fds'] = 'posix' in sys.builtin_module_names

    return subprocess.Popen(*args, **kwargs)


def _enqueue_output(out, queue_):
    for line in iter(out.readline, b''):
        queue_.put(line)


def _add_stderr_to_debug(stderr_queue):
    while True:
        # Try to do some error reporting from the subprocess and print its
        # stderr contents.
        try:
            line = stderr_queue.get_nowait()
            line = line.decode('utf-8', 'replace')
            debug.warning('stderr output: %s' % line.rstrip('\n'))
        except queue.Empty:
            break


def _get_function(name):
    return getattr(functions, name)


def _cleanup_process(process, thread):
    try:
        process.kill()
        process.wait()
    except OSError:
        # Raised if the process is already killed.
        pass
    thread.join()
    for stream in [process.stdin, process.stdout, process.stderr]:
        try:
            stream.close()
        except OSError:
            # Raised if the stream is broken.
            pass


class _InferenceStateProcess:
    def __init__(self, inference_state: 'InferenceState') -> None:
        self._inference_state_weakref = weakref.ref(inference_state)
        self._handles: Dict[int, AccessHandle] = {}

    def get_or_create_access_handle(self, obj):
        id_ = id(obj)
        try:
            return self.get_access_handle(id_)
        except KeyError:
            access = DirectObjectAccess(self._inference_state_weakref(), obj)
            handle = AccessHandle(self, access, id_)
            self.set_access_handle(handle)
            return handle

    def get_access_handle(self, id_):
        return self._handles[id_]

    def set_access_handle(self, handle):
        self._handles[handle.id] = handle


class InferenceStateSameProcess(_InferenceStateProcess):
    """
    Basically just an easy access to functions.py. It has the same API
    as InferenceStateSubprocess and does the same thing without using a subprocess.
    This is necessary for the Interpreter process.
    """
    def __getattr__(self, name):
        return partial(_get_function(name), self._inference_state_weakref())


class InferenceStateSubprocess(_InferenceStateProcess):
    """
    API to functionality which will run in a subprocess.

    This mediates the interaction between an `InferenceState` and the actual
    execution of functionality running within a `CompiledSubprocess`. Available
    functions are defined in `.functions`, though should be accessed via
    attributes on this class of the same name.

    This class is responsible for indicating that the `InferenceState` within
    the subprocess can be removed once the corresponding instance in the parent
    goes away.
    """

    def __init__(
        self,
        inference_state: 'InferenceState',
        compiled_subprocess: 'CompiledSubprocess',
    ) -> None:
        super().__init__(inference_state)
        self._used = False
        self._compiled_subprocess = compiled_subprocess

        # Opaque id we'll pass to the subprocess to identify the context (an
        # `InferenceState`) which should be used for the request. This allows us
        # to make subsequent requests which operate on results from previous
        # ones, while keeping a single subprocess which can work with several
        # contexts in the parent process. Once it is no longer needed(i.e: when
        # this class goes away), we also use this id to indicate that the
        # subprocess can discard the context.
        #
        # Note: this id is deliberately coupled to this class (and not to
        # `InferenceState`) as this class manages access handle mappings which
        # must correspond to those in the subprocess. This approach also avoids
        # race conditions from successive `InferenceState`s with the same object
        # id (as observed while adding support for Python 3.13).
        #
        # This value does not need to be the `id()` of this instance, we merely
        # need to ensure that it enables the (visible) lifetime of the context
        # within the subprocess to match that of this class. We therefore also
        # depend on the semantics of `CompiledSubprocess.delete_inference_state`
        # for correctness.
        self._inference_state_id = id(self)

    def __getattr__(self, name):
        func = _get_function(name)

        def wrapper(*args, **kwargs):
            self._used = True

            result = self._compiled_subprocess.run(
                self._inference_state_id,
                func,
                args=args,
                kwargs=kwargs,
            )
            # IMO it should be possible to create a hook in pickle.load to
            # mess with the loaded objects. However it's extremely complicated
            # to work around this so just do it with this call. ~ dave
            return self._convert_access_handles(result)

        return wrapper

    def _convert_access_handles(self, obj):
        if isinstance(obj, SignatureParam):
            return SignatureParam(*self._convert_access_handles(tuple(obj)))
        elif isinstance(obj, tuple):
            return tuple(self._convert_access_handles(o) for o in obj)
        elif isinstance(obj, list):
            return [self._convert_access_handles(o) for o in obj]
        elif isinstance(obj, AccessHandle):
            try:
                # Rewrite the access handle to one we're already having.
                obj = self.get_access_handle(obj.id)
            except KeyError:
                obj.add_subprocess(self)
                self.set_access_handle(obj)
        elif isinstance(obj, AccessPath):
            return AccessPath(self._convert_access_handles(obj.accesses))
        return obj

    def __del__(self):
        if self._used and not self._compiled_subprocess.is_crashed:
            self._compiled_subprocess.delete_inference_state(self._inference_state_id)


class CompiledSubprocess:
    """
    A subprocess which runs inference within a target environment.

    This class manages the interface to a single instance of such a process as
    well as the lifecycle of the process itself. See `.__main__` and `Listener`
    for the implementation of the subprocess and details of the protocol.

    A single live instance of this is maintained by `jedi.api.environment.Environment`,
    so that typically a single subprocess is used at a time.
    """

    is_crashed = False

    def __init__(self, executable, env_vars=None):
        self._executable = executable
        self._env_vars = env_vars
        self._inference_state_deletion_queue = collections.deque()
        self._cleanup_callable = lambda: None

    def __repr__(self):
        pid = os.getpid()
        return '<%s _executable=%r, is_crashed=%r, pid=%r>' % (
            self.__class__.__name__,
            self._executable,
            self.is_crashed,
            pid,
        )

    @memoize_method
    def _get_process(self):
        debug.dbg('Start environment subprocess %s', self._executable)
        parso_path = sys.modules['parso'].__file__
        args = (
            self._executable,
            _MAIN_PATH,
            os.path.dirname(os.path.dirname(parso_path)),
            '.'.join(str(x) for x in sys.version_info[:3]),
        )
        process = _GeneralizedPopen(
            args,
            stdin=subprocess.PIPE,
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            env=self._env_vars
        )
        self._stderr_queue = queue.Queue()
        self._stderr_thread = t = Thread(
            target=_enqueue_output,
            args=(process.stderr, self._stderr_queue)
        )
        t.daemon = True
        t.start()
        # Ensure the subprocess is properly cleaned up when the object
        # is garbage collected.
        self._cleanup_callable = weakref.finalize(self,
                                                  _cleanup_process,
                                                  process,
                                                  t)
        return process

    def run(self, inference_state_id, function, args=(), kwargs={}):
        # Delete old inference_states.
        while True:
            try:
                delete_id = self._inference_state_deletion_queue.pop()
            except IndexError:
                break
            else:
                self._send(delete_id, None)

        assert callable(function)
        return self._send(inference_state_id, function, args, kwargs)

    def get_sys_path(self):
        return self._send(None, functions.get_sys_path, (), {})

    def _kill(self):
        self.is_crashed = True
        self._cleanup_callable()

    def _send(self, inference_state_id, function, args=(), kwargs={}):
        if self.is_crashed:
            raise InternalError("The subprocess %s has crashed." % self._executable)

        data = inference_state_id, function, args, kwargs
        try:
            pickle_dump(data, self._get_process().stdin, PICKLE_PROTOCOL)
        except BrokenPipeError:
            self._kill()
            raise InternalError("The subprocess %s was killed. Maybe out of memory?"
                                % self._executable)

        try:
            is_exception, traceback, result = pickle_load(self._get_process().stdout)
        except EOFError as eof_error:
            try:
                stderr = self._get_process().stderr.read().decode('utf-8', 'replace')
            except Exception as exc:
                stderr = '<empty/not available (%r)>' % exc
            self._kill()
            _add_stderr_to_debug(self._stderr_queue)
            raise InternalError(
                "The subprocess %s has crashed (%r, stderr=%s)." % (
                    self._executable,
                    eof_error,
                    stderr,
                ))

        _add_stderr_to_debug(self._stderr_queue)

        if is_exception:
            # Replace the attribute error message with a the traceback. It's
            # way more informative.
            result.args = (traceback,)
            raise result
        return result

    def delete_inference_state(self, inference_state_id):
        """
        Indicate that an inference state (in the subprocess) is no longer
        needed.

        The state corresponding to the given id will become inaccessible and the
        id may safely be re-used to refer to a different context.

        Note: it is not guaranteed that the corresponding state will actually be
        deleted immediately.
        """
        # Warning: if changing the semantics of context deletion see the comment
        # in `InferenceStateSubprocess.__init__` regarding potential race
        # conditions.

        # Currently we are not deleting the related state instantly. They only
        # get deleted once the subprocess is used again. It would probably a
        # better solution to move all of this into a thread. However, the memory
        # usage of a single inference_state shouldn't be that high.
        self._inference_state_deletion_queue.append(inference_state_id)


class Listener:
    """
    Main loop for the subprocess which actually does the inference.

    This class runs within the target environment. It listens to instructions
    from the parent process, runs inference and returns the results.

    The subprocess has a long lifetime and is expected to process several
    requests, including for different `InferenceState` instances in the parent.
    See `CompiledSubprocess` for the parent half of the system.

    Communication is via pickled data sent serially over stdin and stdout.
    Stderr is read only if the child process crashes.

    The request protocol is a 4-tuple of:
     * inference_state_id | None: an opaque identifier of the parent's
       `InferenceState`. An `InferenceState` operating over an
       `InterpreterEnvironment` is created within this process for each of
       these, ensuring that each parent context has a corresponding context
       here. This allows context to be persisted between requests. Unless
       `None`, the local `InferenceState` will be passed to the given function
       as the first positional argument.
     * function | None: the function to run. This is expected to be a member of
       `.functions`. `None` indicates that the corresponding inference state is
       no longer needed and should be dropped.
     * args: positional arguments to the `function`. If any of these are
       `AccessHandle` instances they will be adapted to the local
       `InferenceState` before being passed.
     * kwargs: keyword arguments to the `function`. If any of these are
       `AccessHandle` instances they will be adapted to the local
       `InferenceState` before being passed.

    The result protocol is a 3-tuple of either:
     * (False, None, function result): if the function returns without error, or
     * (True, traceback, exception): if the function raises an exception
    """

    def __init__(self):
        self._inference_states = {}

    def _get_inference_state(self, function, inference_state_id):
        from jedi.inference import InferenceState

        try:
            inference_state = self._inference_states[inference_state_id]
        except KeyError:
            from jedi import InterpreterEnvironment
            inference_state = InferenceState(
                # The project is not actually needed. Nothing should need to
                # access it.
                project=None,
                environment=InterpreterEnvironment()
            )
            self._inference_states[inference_state_id] = inference_state
        return inference_state

    def _run(self, inference_state_id, function, args, kwargs):
        if inference_state_id is None:
            return function(*args, **kwargs)
        elif function is None:
            # Warning: if changing the semantics of context deletion see the comment
            # in `InferenceStateSubprocess.__init__` regarding potential race
            # conditions.
            del self._inference_states[inference_state_id]
        else:
            inference_state = self._get_inference_state(function, inference_state_id)

            # Exchange all handles
            args = list(args)
            for i, arg in enumerate(args):
                if isinstance(arg, AccessHandle):
                    args[i] = inference_state.compiled_subprocess.get_access_handle(arg.id)
            for key, value in kwargs.items():
                if isinstance(value, AccessHandle):
                    kwargs[key] = inference_state.compiled_subprocess.get_access_handle(value.id)

            return function(inference_state, *args, **kwargs)

    def listen(self):
        stdout = sys.stdout
        # Mute stdout. Nobody should actually be able to write to it,
        # because stdout is used for IPC.
        sys.stdout = open(os.devnull, 'w')
        stdin = sys.stdin
        stdout = stdout.buffer
        stdin = stdin.buffer

        while True:
            try:
                payload = pickle_load(stdin)
            except EOFError:
                # It looks like the parent process closed.
                # Don't make a big fuss here and just exit.
                exit(0)
            try:
                result = False, None, self._run(*payload)
            except Exception as e:
                result = True, traceback.format_exc(), e

            pickle_dump(result, stdout, PICKLE_PROTOCOL)


class AccessHandle:
    def __init__(
        self,
        subprocess: _InferenceStateProcess,
        access: DirectObjectAccess,
        id_: int,
    ) -> None:
        self.access = access
        self._subprocess = subprocess
        self.id = id_

    def add_subprocess(self, subprocess):
        self._subprocess = subprocess

    def __repr__(self):
        try:
            detail = self.access
        except AttributeError:
            detail = '#' + str(self.id)
        return '<%s of %s>' % (self.__class__.__name__, detail)

    def __getstate__(self):
        return self.id

    def __setstate__(self, state):
        self.id = state

    def __getattr__(self, name):
        if name in ('id', 'access') or name.startswith('_'):
            raise AttributeError("Something went wrong with unpickling")

        # print('getattr', name, file=sys.stderr)
        return partial(self._workaround, name)

    def _workaround(self, name, *args, **kwargs):
        """
        TODO Currently we're passing slice objects around. This should not
        happen. They are also the only unhashable objects that we're passing
        around.
        """
        if args and isinstance(args[0], slice):
            return self._subprocess.get_compiled_method_return(self.id, name, *args, **kwargs)
        return self._cached_results(name, *args, **kwargs)

    @memoize_method
    def _cached_results(self, name, *args, **kwargs):
        return self._subprocess.get_compiled_method_return(self.id, name, *args, **kwargs)



"""
Utility for saving locals.
"""
import sys
from _pydevd_bundle.pydevd_constants import IS_PY313_OR_GREATER
from _pydev_bundle import pydev_log

try:
    import types

    frame_type = types.FrameType
except:
    frame_type = type(sys._getframe())


def is_save_locals_available():
    return save_locals_impl is not None


def save_locals(frame):
    """
    Copy values from locals_dict into the fast stack slots in the given frame.

    Note: the 'save_locals' branch had a different approach wrapping the frame (much more code, but it gives ideas
    on how to save things partially, not the 'whole' locals).
    """
    if not isinstance(frame, frame_type):
        # Fix exception when changing Django variable (receiving DjangoTemplateFrame)
        return

    if save_locals_impl is not None:
        try:
            save_locals_impl(frame)
        except:
            pass


def make_save_locals_impl():
    """
    Factory for the 'save_locals_impl' method. This may seem like a complicated pattern but it is essential that the method is created at
    module load time. Inner imports after module load time would cause an occasional debugger deadlock due to the importer lock and debugger
    lock being taken in different order in  different threads.
    """
    try:
        if "__pypy__" in sys.builtin_module_names:
            import __pypy__  # @UnresolvedImport

            save_locals = __pypy__.locals_to_fast
    except:
        pass
    else:
        if "__pypy__" in sys.builtin_module_names:

            def save_locals_pypy_impl(frame):
                save_locals(frame)

            return save_locals_pypy_impl

    if IS_PY313_OR_GREATER:
        # No longer needed in Python 3.13 (deprecated)
        # See PEP 667
        return None

    try:
        import ctypes

        locals_to_fast = ctypes.pythonapi.PyFrame_LocalsToFast
    except:
        pass
    else:

        def save_locals_ctypes_impl(frame):
            locals_to_fast(ctypes.py_object(frame), ctypes.c_int(0))

        return save_locals_ctypes_impl

    return None


save_locals_impl = make_save_locals_impl()

_SENTINEL = []  # Any mutable will do.


def update_globals_and_locals(updated_globals, initial_globals, frame):
    # We don't have the locals and passed all in globals, so, we have to
    # manually choose how to update the variables.
    #
    # Note that the current implementation is a bit tricky: it does work in general
    # but if we do something as 'some_var = 10' and 'some_var' is already defined to have
    # the value '10' in the globals, we won't actually put that value in the locals
    # (which means that the frame locals won't be updated).
    # Still, the approach to have a single namespace was chosen because it was the only
    # one that enabled creating and using variables during the same evaluation.
    assert updated_globals is not None
    f_locals = None

    removed = set(initial_globals).difference(updated_globals)

    for key, val in updated_globals.items():
        if val is not initial_globals.get(key, _SENTINEL):
            if f_locals is None:
                # Note: we call f_locals only once because each time
                # we call it the values may be reset.
                f_locals = frame.f_locals

            f_locals[key] = val

    if removed:
        if f_locals is None:
            # Note: we call f_locals only once because each time
            # we call it the values may be reset.
            f_locals = frame.f_locals

        for key in removed:
            try:
                del f_locals[key]
            except Exception:
                # Python 3.13.0 has issues here:
                # https://github.com/python/cpython/pull/125616
                # This should be backported from the pull request
                # but we still need to handle it in this version
                try:
                    if key in f_locals:
                        f_locals[key] = None
                except Exception as e:
                    pydev_log.info("Unable to remove key: %s from locals. Exception: %s", key, e)

    if f_locals is not None:
        save_locals(frame)



"""Compiler helpers for the debugger."""
import os
import sys
import tempfile

from IPython.core.compilerop import CachingCompiler


def murmur2_x86(data, seed):
    """Get the murmur2 hash."""
    m = 0x5BD1E995
    data = [chr(d) for d in str.encode(data, "utf8")]
    length = len(data)
    h = seed ^ length
    rounded_end = length & 0xFFFFFFFC
    for i in range(0, rounded_end, 4):
        k = (
            (ord(data[i]) & 0xFF)
            | ((ord(data[i + 1]) & 0xFF) << 8)
            | ((ord(data[i + 2]) & 0xFF) << 16)
            | (ord(data[i + 3]) << 24)
        )
        k = (k * m) & 0xFFFFFFFF
        k ^= k >> 24
        k = (k * m) & 0xFFFFFFFF

        h = (h * m) & 0xFFFFFFFF
        h ^= k

    val = length & 0x03
    k = 0
    if val == 3:
        k = (ord(data[rounded_end + 2]) & 0xFF) << 16
    if val in [2, 3]:
        k |= (ord(data[rounded_end + 1]) & 0xFF) << 8
    if val in [1, 2, 3]:
        k |= ord(data[rounded_end]) & 0xFF
        h ^= k
        h = (h * m) & 0xFFFFFFFF

    h ^= h >> 13
    h = (h * m) & 0xFFFFFFFF
    h ^= h >> 15

    return h


convert_to_long_pathname = lambda filename: filename  # noqa: E731

if sys.platform == "win32":
    try:
        import ctypes
        from ctypes.wintypes import DWORD, LPCWSTR, LPWSTR, MAX_PATH

        _GetLongPathName = ctypes.windll.kernel32.GetLongPathNameW
        _GetLongPathName.argtypes = [LPCWSTR, LPWSTR, DWORD]
        _GetLongPathName.restype = DWORD

        def _convert_to_long_pathname(filename):
            buf = ctypes.create_unicode_buffer(MAX_PATH)
            rv = _GetLongPathName(filename, buf, MAX_PATH)
            if rv != 0 and rv <= MAX_PATH:
                filename = buf.value
            return filename

        # test that it works so if there are any issues we fail just once here
        _convert_to_long_pathname(__file__)
    except Exception:
        pass
    else:
        convert_to_long_pathname = _convert_to_long_pathname


def get_tmp_directory():
    """Get a temp directory."""
    tmp_dir = convert_to_long_pathname(tempfile.gettempdir())
    pid = os.getpid()
    return tmp_dir + os.sep + "ipykernel_" + str(pid)


def get_tmp_hash_seed():
    """Get a temp hash seed."""
    return 0xC70F6907


def get_file_name(code):
    """Get a file name."""
    cell_name = os.environ.get("IPYKERNEL_CELL_NAME")
    if cell_name is None:
        name = murmur2_x86(code, get_tmp_hash_seed())
        cell_name = get_tmp_directory() + os.sep + str(name) + ".py"
    return cell_name


class XCachingCompiler(CachingCompiler):
    """A custom caching compiler."""

    def __init__(self, *args, **kwargs):
        """Initialize the compiler."""
        super().__init__(*args, **kwargs)
        self.log = None

    def get_code_name(self, raw_code, code, number):
        """Get the code name."""
        return get_file_name(raw_code)



#############################################################################
##
## Copyright (C) 2020 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of Qt for Python.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 3 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL3 included in the
## packaging of this file. Please review the following information to
## ensure the GNU Lesser General Public License version 3 requirements
## will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 2.0 or (at your option) the GNU General
## Public license version 3 or any later version approved by the KDE Free
## Qt Foundation. The licenses are as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-2.0.html and
## https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################
from __future__ import annotations

"""
This file contains the exact signatures for all functions in module
PySide2.QtXml, except for defaults which are replaced by "...".
"""

# Module PySide2.QtXml
import PySide2
try:
    import typing
except ImportError:
    from PySide2.support.signature import typing
from PySide2.support.signature.mapping import (
    Virtual, Missing, Invalid, Default, Instance)

from shiboken2 import Shiboken

import PySide2.QtCore
import PySide2.QtXml


class QDomAttr(PySide2.QtXml.QDomNode):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomAttr) -> None: ...


class QDomCDATASection(PySide2.QtXml.QDomText):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomCDATASection) -> None: ...


class QDomCharacterData(PySide2.QtXml.QDomNode):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomCharacterData) -> None: ...


class QDomComment(PySide2.QtXml.QDomCharacterData):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomComment) -> None: ...


class QDomDocument(PySide2.QtXml.QDomNode):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, doctype: PySide2.QtXml.QDomDocumentType) -> None: ...
    @typing.overload
    def __init__(self, name: str) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomDocument) -> None: ...


class QDomDocumentFragment(PySide2.QtXml.QDomNode):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomDocumentFragment) -> None: ...


class QDomDocumentType(PySide2.QtXml.QDomNode):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomDocumentType) -> None: ...


class QDomElement(PySide2.QtXml.QDomNode):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomElement) -> None: ...


class QDomEntity(PySide2.QtXml.QDomNode):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomEntity) -> None: ...


class QDomEntityReference(PySide2.QtXml.QDomNode):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomEntityReference) -> None: ...


class QDomImplementation(Shiboken.Object):
    AcceptInvalidChars       : QDomImplementation.InvalidDataPolicy = ... # 0x0
    DropInvalidChars         : QDomImplementation.InvalidDataPolicy = ... # 0x1
    ReturnNullNode           : QDomImplementation.InvalidDataPolicy = ... # 0x2

    class InvalidDataPolicy(Shiboken.Enum):
        AcceptInvalidChars       : QDomImplementation.InvalidDataPolicy = ... # 0x0
        DropInvalidChars         : QDomImplementation.InvalidDataPolicy = ... # 0x1
        ReturnNullNode           : QDomImplementation.InvalidDataPolicy = ... # 0x2

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide2.QtXml.QDomImplementation) -> None: ...


class QDomNamedNodeMap(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide2.QtXml.QDomNamedNodeMap) -> None: ...


class QDomNode(Shiboken.Object):
    EncodingFromDocument     : QDomNode.EncodingPolicy = ... # 0x1
    EncodingFromTextStream   : QDomNode.EncodingPolicy = ... # 0x2
    ElementNode              : QDomNode.NodeType = ... # 0x1
    AttributeNode            : QDomNode.NodeType = ... # 0x2
    TextNode                 : QDomNode.NodeType = ... # 0x3
    CDATASectionNode         : QDomNode.NodeType = ... # 0x4
    EntityReferenceNode      : QDomNode.NodeType = ... # 0x5
    EntityNode               : QDomNode.NodeType = ... # 0x6
    ProcessingInstructionNode: QDomNode.NodeType = ... # 0x7
    CommentNode              : QDomNode.NodeType = ... # 0x8
    DocumentNode             : QDomNode.NodeType = ... # 0x9
    DocumentTypeNode         : QDomNode.NodeType = ... # 0xa
    DocumentFragmentNode     : QDomNode.NodeType = ... # 0xb
    NotationNode             : QDomNode.NodeType = ... # 0xc
    BaseNode                 : QDomNode.NodeType = ... # 0x15
    CharacterDataNode        : QDomNode.NodeType = ... # 0x16

    class EncodingPolicy(Shiboken.Enum):
        EncodingFromDocument     : QDomNode.EncodingPolicy = ... # 0x1
        EncodingFromTextStream   : QDomNode.EncodingPolicy = ... # 0x2

    class NodeType(Shiboken.Enum):
        ElementNode              : QDomNode.NodeType = ... # 0x1
        AttributeNode            : QDomNode.NodeType = ... # 0x2
        TextNode                 : QDomNode.NodeType = ... # 0x3
        CDATASectionNode         : QDomNode.NodeType = ... # 0x4
        EntityReferenceNode      : QDomNode.NodeType = ... # 0x5
        EntityNode               : QDomNode.NodeType = ... # 0x6
        ProcessingInstructionNode: QDomNode.NodeType = ... # 0x7
        CommentNode              : QDomNode.NodeType = ... # 0x8
        DocumentNode             : QDomNode.NodeType = ... # 0x9
        DocumentTypeNode         : QDomNode.NodeType = ... # 0xa
        DocumentFragmentNode     : QDomNode.NodeType = ... # 0xb
        NotationNode             : QDomNode.NodeType = ... # 0xc
        BaseNode                 : QDomNode.NodeType = ... # 0x15
        CharacterDataNode        : QDomNode.NodeType = ... # 0x16

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide2.QtXml.QDomNode) -> None: ...


class QDomNodeList(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide2.QtXml.QDomNodeList) -> None: ...


class QDomNotation(PySide2.QtXml.QDomNode):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomNotation) -> None: ...


class QDomProcessingInstruction(PySide2.QtXml.QDomNode):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomProcessingInstruction) -> None: ...


class QDomText(PySide2.QtXml.QDomCharacterData):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: PySide2.QtXml.QDomText) -> None: ...


class QXmlAttributes(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide2.QtXml.QXmlAttributes) -> None: ...


class QXmlContentHandler(Shiboken.Object):

    def __init__(self) -> None: ...


class QXmlDTDHandler(Shiboken.Object):

    def __init__(self) -> None: ...


class QXmlDeclHandler(Shiboken.Object):

    def __init__(self) -> None: ...


class QXmlDefaultHandler(PySide2.QtXml.QXmlContentHandler, PySide2.QtXml.QXmlErrorHandler, PySide2.QtXml.QXmlDTDHandler, PySide2.QtXml.QXmlEntityResolver, PySide2.QtXml.QXmlLexicalHandler, PySide2.QtXml.QXmlDeclHandler):

    def __init__(self) -> None: ...


class QXmlEntityResolver(Shiboken.Object):

    def __init__(self) -> None: ...


class QXmlErrorHandler(Shiboken.Object):

    def __init__(self) -> None: ...


class QXmlInputSource(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, dev: PySide2.QtCore.QIODevice) -> None: ...


class QXmlLexicalHandler(Shiboken.Object):

    def __init__(self) -> None: ...


class QXmlLocator(Shiboken.Object):

    def __init__(self) -> None: ...


class QXmlNamespaceSupport(Shiboken.Object):

    def __init__(self) -> None: ...


class QXmlParseException(Shiboken.Object):

    @typing.overload
    def __init__(self, name: str = ..., c: int = ..., l: int = ..., p: str = ..., s: str = ...) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtXml.QXmlParseException) -> None: ...


class QXmlReader(Shiboken.Object):

    def __init__(self) -> None: ...


class QXmlSimpleReader(PySide2.QtXml.QXmlReader):

    def __init__(self) -> None: ...


# eof



from typing import Dict, Tuple

IMPORT_MAPPING: Dict[str, str]
NAME_MAPPING: Dict[Tuple[str, str], Tuple[str, str]]
PYTHON2_EXCEPTIONS: Tuple[str, ...]
MULTIPROCESSING_EXCEPTIONS: Tuple[str, ...]
REVERSE_IMPORT_MAPPING: Dict[str, str]
REVERSE_NAME_MAPPING: Dict[Tuple[str, str], Tuple[str, str]]
PYTHON3_OSERROR_EXCEPTIONS: Tuple[str, ...]
PYTHON3_IMPORTERROR_EXCEPTIONS: Tuple[str, ...]



built_modules = list(name for name in
    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;X11Extras;Xml;XmlPatterns;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLFunctions;RemoteObjects;SerialPort;Svg;UiTools"
    .split(";"))

shiboken_library_soversion = str(5.15)
pyside_library_soversion = str(5.15)

version = "5.15.12"
version_info = (5, 15, 12, "", "")

__build_date__ = '2026-03-26T17:34:18+00:00'

__build_commit_hash__ = 'b642cfa372ca04f8a09f2bc94f8718ab23911ac1'
__build_commit_hash_described__ = 'v5.15.12-lts-lgpl'

__setup_py_package_version__ = '5.15.12'



import sys
import Metashape

def append_console(context, text, text_type):
    for line in text.split('\n'):
        context.append(line.replace('\t', '    ') + "\n", text_type)


def get_console(context):
    from code import InteractiveConsole

    if context.console is None:
        namespace = {}

        namespace["__builtins__"] = sys.modules["builtins"]
        namespace["Metashape"] = Metashape

        context.console = InteractiveConsole(locals=namespace, filename="<console>")

    return context.console


def expand(line, cursor, namespace):
    import os
    import rlcompleter
    import inspect

    if line[:cursor].strip().endswith('('):

        scrollback = ''

        func_word = line[:cursor].split()[-1][:-1]

        try:
            func = eval(func_word, namespace)
        except Exception:
            func = None

        if func:
            scrollback = inspect.getdoc(func)

    else:
        word = line[:cursor].rpartition(' ')[2]

        matches = []

        if word:
            completer = rlcompleter.Completer(namespace)
            completer.complete(word, 0)
            matches = sorted(set(completer.matches))

        matches = [match for match in matches if not('._' in match)]

        if len(matches) == 1:
            scrollback = ''
        else:
            scrollback = '  '.join([m.split('.')[-1] for m in matches])

        prefix = os.path.commonprefix(matches)[len(word):]
        if prefix:
            line = line[:cursor] + prefix + line[cursor:]
            cursor += len(prefix)
            if prefix.endswith('('):
                return expand(line, cursor, namespace)

    return line, cursor, scrollback


def execute(context):
    import io

    stdin_backup = sys.stdin
    sys.stdin = None

    line = ""
    is_multiline = False

    line = context.command

    try:
        line_exec = line if line.strip() else "\n"

        is_multiline = get_console(context).push(line_exec)
    except:
        import traceback
        stderr.write(traceback.format_exc())

    sys.last_traceback = None

    context.append(context.prompt + line + "\n", 'INPUT')

    if is_multiline:
        context.prompt = '... '
    else:
        context.prompt = '>>> '

    context.cursor = 0
    context.command = ""

    sys.stdin = stdin_backup

    return True


def autocomplete(context):

    stdin_backup = sys.stdin
    sys.stdin = None

    scrollback = ""
    scrollback_error = ""

    try:
        context.command, context.cursor, scrollback = expand(context.command, context.cursor, get_console(context).locals)
    except:
        import traceback
        scrollback_error = traceback.format_exc()

    if scrollback != '':
        context.append(context.prompt + context.command + "\n", 'INPUT')

    if scrollback:
        append_console(context, scrollback, 'INFO')

    if scrollback_error:
        append_console(context, scrollback_error, 'ERROR')

    sys.stdin = stdin_backup

    return True


def init(context):
    context.prompt = '>>> '

    return True



#############################################################################
##
## Copyright (C) 2020 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of Qt for Python.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 3 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL3 included in the
## packaging of this file. Please review the following information to
## ensure the GNU Lesser General Public License version 3 requirements
## will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 2.0 or (at your option) the GNU General
## Public license version 3 or any later version approved by the KDE Free
## Qt Foundation. The licenses are as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-2.0.html and
## https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################
from __future__ import annotations

"""
This file contains the exact signatures for all functions in module
PySide2.QtPrintSupport, except for defaults which are replaced by "...".
"""

# Module PySide2.QtPrintSupport
import PySide2
try:
    import typing
except ImportError:
    from PySide2.support.signature import typing
from PySide2.support.signature.mapping import (
    Virtual, Missing, Invalid, Default, Instance)

from shiboken2 import Shiboken

import PySide2.QtCore
import PySide2.QtGui
import PySide2.QtWidgets
import PySide2.QtPrintSupport


class QAbstractPrintDialog(PySide2.QtWidgets.QDialog):
    None_                    : QAbstractPrintDialog.PrintDialogOption = ... # 0x0
    PrintToFile              : QAbstractPrintDialog.PrintDialogOption = ... # 0x1
    PrintSelection           : QAbstractPrintDialog.PrintDialogOption = ... # 0x2
    PrintPageRange           : QAbstractPrintDialog.PrintDialogOption = ... # 0x4
    PrintShowPageSize        : QAbstractPrintDialog.PrintDialogOption = ... # 0x8
    PrintCollateCopies       : QAbstractPrintDialog.PrintDialogOption = ... # 0x10
    DontUseSheet             : QAbstractPrintDialog.PrintDialogOption = ... # 0x20
    PrintCurrentPage         : QAbstractPrintDialog.PrintDialogOption = ... # 0x40
    AllPages                 : QAbstractPrintDialog.PrintRange = ... # 0x0
    Selection                : QAbstractPrintDialog.PrintRange = ... # 0x1
    PageRange                : QAbstractPrintDialog.PrintRange = ... # 0x2
    CurrentPage              : QAbstractPrintDialog.PrintRange = ... # 0x3

    class PrintDialogOption(Shiboken.Enum):
        None_                    : QAbstractPrintDialog.PrintDialogOption = ... # 0x0
        PrintToFile              : QAbstractPrintDialog.PrintDialogOption = ... # 0x1
        PrintSelection           : QAbstractPrintDialog.PrintDialogOption = ... # 0x2
        PrintPageRange           : QAbstractPrintDialog.PrintDialogOption = ... # 0x4
        PrintShowPageSize        : QAbstractPrintDialog.PrintDialogOption = ... # 0x8
        PrintCollateCopies       : QAbstractPrintDialog.PrintDialogOption = ... # 0x10
        DontUseSheet             : QAbstractPrintDialog.PrintDialogOption = ... # 0x20
        PrintCurrentPage         : QAbstractPrintDialog.PrintDialogOption = ... # 0x40

    class PrintDialogOptions(object): ...

    class PrintRange(Shiboken.Enum):
        AllPages                 : QAbstractPrintDialog.PrintRange = ... # 0x0
        Selection                : QAbstractPrintDialog.PrintRange = ... # 0x1
        PageRange                : QAbstractPrintDialog.PrintRange = ... # 0x2
        CurrentPage              : QAbstractPrintDialog.PrintRange = ... # 0x3

    def __init__(self, printer: PySide2.QtPrintSupport.QPrinter, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ...) -> None: ...


class QPageSetupDialog(PySide2.QtWidgets.QDialog):

    @typing.overload
    def __init__(self, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ...) -> None: ...
    @typing.overload
    def __init__(self, printer: PySide2.QtPrintSupport.QPrinter, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ...) -> None: ...


class QPrintDialog(PySide2.QtPrintSupport.QAbstractPrintDialog):

    @typing.overload
    def __init__(self, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ...) -> None: ...
    @typing.overload
    def __init__(self, printer: PySide2.QtPrintSupport.QPrinter, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ...) -> None: ...


class QPrintEngine(Shiboken.Object):
    PPK_CollateCopies        : QPrintEngine.PrintEnginePropertyKey = ... # 0x0
    PPK_ColorMode            : QPrintEngine.PrintEnginePropertyKey = ... # 0x1
    PPK_Creator              : QPrintEngine.PrintEnginePropertyKey = ... # 0x2
    PPK_DocumentName         : QPrintEngine.PrintEnginePropertyKey = ... # 0x3
    PPK_FullPage             : QPrintEngine.PrintEnginePropertyKey = ... # 0x4
    PPK_NumberOfCopies       : QPrintEngine.PrintEnginePropertyKey = ... # 0x5
    PPK_Orientation          : QPrintEngine.PrintEnginePropertyKey = ... # 0x6
    PPK_OutputFileName       : QPrintEngine.PrintEnginePropertyKey = ... # 0x7
    PPK_PageOrder            : QPrintEngine.PrintEnginePropertyKey = ... # 0x8
    PPK_PageRect             : QPrintEngine.PrintEnginePropertyKey = ... # 0x9
    PPK_PageSize             : QPrintEngine.PrintEnginePropertyKey = ... # 0xa
    PPK_PaperSize            : QPrintEngine.PrintEnginePropertyKey = ... # 0xa
    PPK_PaperRect            : QPrintEngine.PrintEnginePropertyKey = ... # 0xb
    PPK_PaperSource          : QPrintEngine.PrintEnginePropertyKey = ... # 0xc
    PPK_PrinterName          : QPrintEngine.PrintEnginePropertyKey = ... # 0xd
    PPK_PrinterProgram       : QPrintEngine.PrintEnginePropertyKey = ... # 0xe
    PPK_Resolution           : QPrintEngine.PrintEnginePropertyKey = ... # 0xf
    PPK_SelectionOption      : QPrintEngine.PrintEnginePropertyKey = ... # 0x10
    PPK_SupportedResolutions : QPrintEngine.PrintEnginePropertyKey = ... # 0x11
    PPK_WindowsPageSize      : QPrintEngine.PrintEnginePropertyKey = ... # 0x12
    PPK_FontEmbedding        : QPrintEngine.PrintEnginePropertyKey = ... # 0x13
    PPK_Duplex               : QPrintEngine.PrintEnginePropertyKey = ... # 0x14
    PPK_PaperSources         : QPrintEngine.PrintEnginePropertyKey = ... # 0x15
    PPK_CustomPaperSize      : QPrintEngine.PrintEnginePropertyKey = ... # 0x16
    PPK_PageMargins          : QPrintEngine.PrintEnginePropertyKey = ... # 0x17
    PPK_CopyCount            : QPrintEngine.PrintEnginePropertyKey = ... # 0x18
    PPK_SupportsMultipleCopies: QPrintEngine.PrintEnginePropertyKey = ... # 0x19
    PPK_PaperName            : QPrintEngine.PrintEnginePropertyKey = ... # 0x1a
    PPK_QPageSize            : QPrintEngine.PrintEnginePropertyKey = ... # 0x1b
    PPK_QPageMargins         : QPrintEngine.PrintEnginePropertyKey = ... # 0x1c
    PPK_QPageLayout          : QPrintEngine.PrintEnginePropertyKey = ... # 0x1d
    PPK_CustomBase           : QPrintEngine.PrintEnginePropertyKey = ... # 0xff00

    class PrintEnginePropertyKey(Shiboken.Enum):
        PPK_CollateCopies        : QPrintEngine.PrintEnginePropertyKey = ... # 0x0
        PPK_ColorMode            : QPrintEngine.PrintEnginePropertyKey = ... # 0x1
        PPK_Creator              : QPrintEngine.PrintEnginePropertyKey = ... # 0x2
        PPK_DocumentName         : QPrintEngine.PrintEnginePropertyKey = ... # 0x3
        PPK_FullPage             : QPrintEngine.PrintEnginePropertyKey = ... # 0x4
        PPK_NumberOfCopies       : QPrintEngine.PrintEnginePropertyKey = ... # 0x5
        PPK_Orientation          : QPrintEngine.PrintEnginePropertyKey = ... # 0x6
        PPK_OutputFileName       : QPrintEngine.PrintEnginePropertyKey = ... # 0x7
        PPK_PageOrder            : QPrintEngine.PrintEnginePropertyKey = ... # 0x8
        PPK_PageRect             : QPrintEngine.PrintEnginePropertyKey = ... # 0x9
        PPK_PageSize             : QPrintEngine.PrintEnginePropertyKey = ... # 0xa
        PPK_PaperSize            : QPrintEngine.PrintEnginePropertyKey = ... # 0xa
        PPK_PaperRect            : QPrintEngine.PrintEnginePropertyKey = ... # 0xb
        PPK_PaperSource          : QPrintEngine.PrintEnginePropertyKey = ... # 0xc
        PPK_PrinterName          : QPrintEngine.PrintEnginePropertyKey = ... # 0xd
        PPK_PrinterProgram       : QPrintEngine.PrintEnginePropertyKey = ... # 0xe
        PPK_Resolution           : QPrintEngine.PrintEnginePropertyKey = ... # 0xf
        PPK_SelectionOption      : QPrintEngine.PrintEnginePropertyKey = ... # 0x10
        PPK_SupportedResolutions : QPrintEngine.PrintEnginePropertyKey = ... # 0x11
        PPK_WindowsPageSize      : QPrintEngine.PrintEnginePropertyKey = ... # 0x12
        PPK_FontEmbedding        : QPrintEngine.PrintEnginePropertyKey = ... # 0x13
        PPK_Duplex               : QPrintEngine.PrintEnginePropertyKey = ... # 0x14
        PPK_PaperSources         : QPrintEngine.PrintEnginePropertyKey = ... # 0x15
        PPK_CustomPaperSize      : QPrintEngine.PrintEnginePropertyKey = ... # 0x16
        PPK_PageMargins          : QPrintEngine.PrintEnginePropertyKey = ... # 0x17
        PPK_CopyCount            : QPrintEngine.PrintEnginePropertyKey = ... # 0x18
        PPK_SupportsMultipleCopies: QPrintEngine.PrintEnginePropertyKey = ... # 0x19
        PPK_PaperName            : QPrintEngine.PrintEnginePropertyKey = ... # 0x1a
        PPK_QPageSize            : QPrintEngine.PrintEnginePropertyKey = ... # 0x1b
        PPK_QPageMargins         : QPrintEngine.PrintEnginePropertyKey = ... # 0x1c
        PPK_QPageLayout          : QPrintEngine.PrintEnginePropertyKey = ... # 0x1d
        PPK_CustomBase           : QPrintEngine.PrintEnginePropertyKey = ... # 0xff00

    def __init__(self) -> None: ...


class QPrintPreviewDialog(PySide2.QtWidgets.QDialog):

    @typing.overload
    def __init__(self, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ..., flags: PySide2.QtCore.Qt.WindowFlags = ...) -> None: ...
    @typing.overload
    def __init__(self, printer: PySide2.QtPrintSupport.QPrinter, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ..., flags: PySide2.QtCore.Qt.WindowFlags = ...) -> None: ...


class QPrintPreviewWidget(PySide2.QtWidgets.QWidget):
    SinglePageView           : QPrintPreviewWidget.ViewMode = ... # 0x0
    FacingPagesView          : QPrintPreviewWidget.ViewMode = ... # 0x1
    AllPagesView             : QPrintPreviewWidget.ViewMode = ... # 0x2
    CustomZoom               : QPrintPreviewWidget.ZoomMode = ... # 0x0
    FitToWidth               : QPrintPreviewWidget.ZoomMode = ... # 0x1
    FitInView                : QPrintPreviewWidget.ZoomMode = ... # 0x2

    class ViewMode(Shiboken.Enum):
        SinglePageView           : QPrintPreviewWidget.ViewMode = ... # 0x0
        FacingPagesView          : QPrintPreviewWidget.ViewMode = ... # 0x1
        AllPagesView             : QPrintPreviewWidget.ViewMode = ... # 0x2

    class ZoomMode(Shiboken.Enum):
        CustomZoom               : QPrintPreviewWidget.ZoomMode = ... # 0x0
        FitToWidth               : QPrintPreviewWidget.ZoomMode = ... # 0x1
        FitInView                : QPrintPreviewWidget.ZoomMode = ... # 0x2

    @typing.overload
    def __init__(self, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ..., flags: PySide2.QtCore.Qt.WindowFlags = ...) -> None: ...
    @typing.overload
    def __init__(self, printer: PySide2.QtPrintSupport.QPrinter, parent: typing.Optional[PySide2.QtWidgets.QWidget] = ..., flags: PySide2.QtCore.Qt.WindowFlags = ...) -> None: ...


class QPrinter(PySide2.QtGui.QPagedPaintDevice):
    GrayScale                : QPrinter.ColorMode = ... # 0x0
    Color                    : QPrinter.ColorMode = ... # 0x1
    DuplexNone               : QPrinter.DuplexMode = ... # 0x0
    DuplexAuto               : QPrinter.DuplexMode = ... # 0x1
    DuplexLongSide           : QPrinter.DuplexMode = ... # 0x2
    DuplexShortSide          : QPrinter.DuplexMode = ... # 0x3
    Portrait                 : QPrinter.Orientation = ... # 0x0
    Landscape                : QPrinter.Orientation = ... # 0x1
    NativeFormat             : QPrinter.OutputFormat = ... # 0x0
    PdfFormat                : QPrinter.OutputFormat = ... # 0x1
    FirstPageFirst           : QPrinter.PageOrder = ... # 0x0
    LastPageFirst            : QPrinter.PageOrder = ... # 0x1
    OnlyOne                  : QPrinter.PaperSource = ... # 0x0
    Upper                    : QPrinter.PaperSource = ... # 0x0
    Lower                    : QPrinter.PaperSource = ... # 0x1
    Middle                   : QPrinter.PaperSource = ... # 0x2
    Manual                   : QPrinter.PaperSource = ... # 0x3
    Envelope                 : QPrinter.PaperSource = ... # 0x4
    EnvelopeManual           : QPrinter.PaperSource = ... # 0x5
    Auto                     : QPrinter.PaperSource = ... # 0x6
    Tractor                  : QPrinter.PaperSource = ... # 0x7
    SmallFormat              : QPrinter.PaperSource = ... # 0x8
    LargeFormat              : QPrinter.PaperSource = ... # 0x9
    LargeCapacity            : QPrinter.PaperSource = ... # 0xa
    Cassette                 : QPrinter.PaperSource = ... # 0xb
    FormSource               : QPrinter.PaperSource = ... # 0xc
    MaxPageSource            : QPrinter.PaperSource = ... # 0xd
    CustomSource             : QPrinter.PaperSource = ... # 0xe
    LastPaperSource          : QPrinter.PaperSource = ... # 0xe
    AllPages                 : QPrinter.PrintRange = ... # 0x0
    Selection                : QPrinter.PrintRange = ... # 0x1
    PageRange                : QPrinter.PrintRange = ... # 0x2
    CurrentPage              : QPrinter.PrintRange = ... # 0x3
    ScreenResolution         : QPrinter.PrinterMode = ... # 0x0
    PrinterResolution        : QPrinter.PrinterMode = ... # 0x1
    HighResolution           : QPrinter.PrinterMode = ... # 0x2
    Idle                     : QPrinter.PrinterState = ... # 0x0
    Active                   : QPrinter.PrinterState = ... # 0x1
    Aborted                  : QPrinter.PrinterState = ... # 0x2
    Error                    : QPrinter.PrinterState = ... # 0x3
    Millimeter               : QPrinter.Unit = ... # 0x0
    Point                    : QPrinter.Unit = ... # 0x1
    Inch                     : QPrinter.Unit = ... # 0x2
    Pica                     : QPrinter.Unit = ... # 0x3
    Didot                    : QPrinter.Unit = ... # 0x4
    Cicero                   : QPrinter.Unit = ... # 0x5
    DevicePixel              : QPrinter.Unit = ... # 0x6

    class ColorMode(Shiboken.Enum):
        GrayScale                : QPrinter.ColorMode = ... # 0x0
        Color                    : QPrinter.ColorMode = ... # 0x1

    class DuplexMode(Shiboken.Enum):
        DuplexNone               : QPrinter.DuplexMode = ... # 0x0
        DuplexAuto               : QPrinter.DuplexMode = ... # 0x1
        DuplexLongSide           : QPrinter.DuplexMode = ... # 0x2
        DuplexShortSide          : QPrinter.DuplexMode = ... # 0x3

    class Orientation(Shiboken.Enum):
        Portrait                 : QPrinter.Orientation = ... # 0x0
        Landscape                : QPrinter.Orientation = ... # 0x1

    class OutputFormat(Shiboken.Enum):
        NativeFormat             : QPrinter.OutputFormat = ... # 0x0
        PdfFormat                : QPrinter.OutputFormat = ... # 0x1

    class PageOrder(Shiboken.Enum):
        FirstPageFirst           : QPrinter.PageOrder = ... # 0x0
        LastPageFirst            : QPrinter.PageOrder = ... # 0x1

    class PaperSource(Shiboken.Enum):
        OnlyOne                  : QPrinter.PaperSource = ... # 0x0
        Upper                    : QPrinter.PaperSource = ... # 0x0
        Lower                    : QPrinter.PaperSource = ... # 0x1
        Middle                   : QPrinter.PaperSource = ... # 0x2
        Manual                   : QPrinter.PaperSource = ... # 0x3
        Envelope                 : QPrinter.PaperSource = ... # 0x4
        EnvelopeManual           : QPrinter.PaperSource = ... # 0x5
        Auto                     : QPrinter.PaperSource = ... # 0x6
        Tractor                  : QPrinter.PaperSource = ... # 0x7
        SmallFormat              : QPrinter.PaperSource = ... # 0x8
        LargeFormat              : QPrinter.PaperSource = ... # 0x9
        LargeCapacity            : QPrinter.PaperSource = ... # 0xa
        Cassette                 : QPrinter.PaperSource = ... # 0xb
        FormSource               : QPrinter.PaperSource = ... # 0xc
        MaxPageSource            : QPrinter.PaperSource = ... # 0xd
        CustomSource             : QPrinter.PaperSource = ... # 0xe
        LastPaperSource          : QPrinter.PaperSource = ... # 0xe

    class PrintRange(Shiboken.Enum):
        AllPages                 : QPrinter.PrintRange = ... # 0x0
        Selection                : QPrinter.PrintRange = ... # 0x1
        PageRange                : QPrinter.PrintRange = ... # 0x2
        CurrentPage              : QPrinter.PrintRange = ... # 0x3

    class PrinterMode(Shiboken.Enum):
        ScreenResolution         : QPrinter.PrinterMode = ... # 0x0
        PrinterResolution        : QPrinter.PrinterMode = ... # 0x1
        HighResolution           : QPrinter.PrinterMode = ... # 0x2

    class PrinterState(Shiboken.Enum):
        Idle                     : QPrinter.PrinterState = ... # 0x0
        Active                   : QPrinter.PrinterState = ... # 0x1
        Aborted                  : QPrinter.PrinterState = ... # 0x2
        Error                    : QPrinter.PrinterState = ... # 0x3

    class Unit(Shiboken.Enum):
        Millimeter               : QPrinter.Unit = ... # 0x0
        Point                    : QPrinter.Unit = ... # 0x1
        Inch                     : QPrinter.Unit = ... # 0x2
        Pica                     : QPrinter.Unit = ... # 0x3
        Didot                    : QPrinter.Unit = ... # 0x4
        Cicero                   : QPrinter.Unit = ... # 0x5
        DevicePixel              : QPrinter.Unit = ... # 0x6

    @typing.overload
    def __init__(self, mode: PySide2.QtPrintSupport.QPrinter.PrinterMode = ...) -> None: ...
    @typing.overload
    def __init__(self, printer: PySide2.QtPrintSupport.QPrinterInfo, mode: PySide2.QtPrintSupport.QPrinter.PrinterMode = ...) -> None: ...


class QPrinterInfo(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtPrintSupport.QPrinterInfo) -> None: ...
    @typing.overload
    def __init__(self, printer: PySide2.QtPrintSupport.QPrinter) -> None: ...


# eof



#############################################################################
##
## Copyright (C) 2020 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of Qt for Python.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 3 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL3 included in the
## packaging of this file. Please review the following information to
## ensure the GNU Lesser General Public License version 3 requirements
## will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 2.0 or (at your option) the GNU General
## Public license version 3 or any later version approved by the KDE Free
## Qt Foundation. The licenses are as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-2.0.html and
## https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################
from __future__ import annotations

"""
This file contains the exact signatures for all functions in module
PySide2.QtXmlPatterns, except for defaults which are replaced by "...".
"""

# Module PySide2.QtXmlPatterns
import PySide2
try:
    import typing
except ImportError:
    from PySide2.support.signature import typing
from PySide2.support.signature.mapping import (
    Virtual, Missing, Invalid, Default, Instance)

from shiboken2 import Shiboken

import PySide2.QtCore
import PySide2.QtXmlPatterns


class QAbstractMessageHandler(PySide2.QtCore.QObject):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...


class QAbstractUriResolver(PySide2.QtCore.QObject):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...


class QAbstractXmlNodeModel(Shiboken.Object):
    InheritNamespaces        : QAbstractXmlNodeModel.NodeCopySetting = ... # 0x1
    PreserveNamespaces       : QAbstractXmlNodeModel.NodeCopySetting = ... # 0x2
    Parent                   : QAbstractXmlNodeModel.SimpleAxis = ... # 0x0
    FirstChild               : QAbstractXmlNodeModel.SimpleAxis = ... # 0x1
    PreviousSibling          : QAbstractXmlNodeModel.SimpleAxis = ... # 0x2
    NextSibling              : QAbstractXmlNodeModel.SimpleAxis = ... # 0x3

    class NodeCopySetting(Shiboken.Enum):
        InheritNamespaces        : QAbstractXmlNodeModel.NodeCopySetting = ... # 0x1
        PreserveNamespaces       : QAbstractXmlNodeModel.NodeCopySetting = ... # 0x2

    class SimpleAxis(Shiboken.Enum):
        Parent                   : QAbstractXmlNodeModel.SimpleAxis = ... # 0x0
        FirstChild               : QAbstractXmlNodeModel.SimpleAxis = ... # 0x1
        PreviousSibling          : QAbstractXmlNodeModel.SimpleAxis = ... # 0x2
        NextSibling              : QAbstractXmlNodeModel.SimpleAxis = ... # 0x3

    def __init__(self) -> None: ...


class QAbstractXmlReceiver(Shiboken.Object):

    def __init__(self) -> None: ...


class QSourceLocation(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtXmlPatterns.QSourceLocation) -> None: ...
    @typing.overload
    def __init__(self, uri: PySide2.QtCore.QUrl, line: int = ..., column: int = ...) -> None: ...


class QXmlFormatter(PySide2.QtXmlPatterns.QXmlSerializer):

    def __init__(self, query: PySide2.QtXmlPatterns.QXmlQuery, outputDevice: PySide2.QtCore.QIODevice) -> None: ...


class QXmlItem(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, atomicValue: typing.Any) -> None: ...
    @typing.overload
    def __init__(self, node: PySide2.QtXmlPatterns.QXmlNodeModelIndex) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtXmlPatterns.QXmlItem) -> None: ...


class QXmlName(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, namePool: PySide2.QtXmlPatterns.QXmlNamePool, localName: str, namespaceURI: str = ..., prefix: str = ...) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtXmlPatterns.QXmlName) -> None: ...


class QXmlNamePool(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtXmlPatterns.QXmlNamePool) -> None: ...


class QXmlNodeModelIndex(Shiboken.Object):
    Precedes                 : QXmlNodeModelIndex.DocumentOrder = ... # -0x1
    Is                       : QXmlNodeModelIndex.DocumentOrder = ... # 0x0
    Follows                  : QXmlNodeModelIndex.DocumentOrder = ... # 0x1
    Attribute                : QXmlNodeModelIndex.NodeKind = ... # 0x1
    Comment                  : QXmlNodeModelIndex.NodeKind = ... # 0x2
    Document                 : QXmlNodeModelIndex.NodeKind = ... # 0x4
    Element                  : QXmlNodeModelIndex.NodeKind = ... # 0x8
    Namespace                : QXmlNodeModelIndex.NodeKind = ... # 0x10
    ProcessingInstruction    : QXmlNodeModelIndex.NodeKind = ... # 0x20
    Text                     : QXmlNodeModelIndex.NodeKind = ... # 0x40

    class DocumentOrder(Shiboken.Enum):
        Precedes                 : QXmlNodeModelIndex.DocumentOrder = ... # -0x1
        Is                       : QXmlNodeModelIndex.DocumentOrder = ... # 0x0
        Follows                  : QXmlNodeModelIndex.DocumentOrder = ... # 0x1

    class NodeKind(Shiboken.Enum):
        Attribute                : QXmlNodeModelIndex.NodeKind = ... # 0x1
        Comment                  : QXmlNodeModelIndex.NodeKind = ... # 0x2
        Document                 : QXmlNodeModelIndex.NodeKind = ... # 0x4
        Element                  : QXmlNodeModelIndex.NodeKind = ... # 0x8
        Namespace                : QXmlNodeModelIndex.NodeKind = ... # 0x10
        ProcessingInstruction    : QXmlNodeModelIndex.NodeKind = ... # 0x20
        Text                     : QXmlNodeModelIndex.NodeKind = ... # 0x40

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtXmlPatterns.QXmlNodeModelIndex) -> None: ...


class QXmlQuery(Shiboken.Object):
    XQuery10                 : QXmlQuery.QueryLanguage = ... # 0x1
    XSLT20                   : QXmlQuery.QueryLanguage = ... # 0x2
    XmlSchema11IdentityConstraintSelector: QXmlQuery.QueryLanguage = ... # 0x400
    XmlSchema11IdentityConstraintField: QXmlQuery.QueryLanguage = ... # 0x800
    XPath20                  : QXmlQuery.QueryLanguage = ... # 0x1000

    class QueryLanguage(Shiboken.Enum):
        XQuery10                 : QXmlQuery.QueryLanguage = ... # 0x1
        XSLT20                   : QXmlQuery.QueryLanguage = ... # 0x2
        XmlSchema11IdentityConstraintSelector: QXmlQuery.QueryLanguage = ... # 0x400
        XmlSchema11IdentityConstraintField: QXmlQuery.QueryLanguage = ... # 0x800
        XPath20                  : QXmlQuery.QueryLanguage = ... # 0x1000

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, np: PySide2.QtXmlPatterns.QXmlNamePool) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtXmlPatterns.QXmlQuery) -> None: ...
    @typing.overload
    def __init__(self, queryLanguage: PySide2.QtXmlPatterns.QXmlQuery.QueryLanguage, np: PySide2.QtXmlPatterns.QXmlNamePool = ...) -> None: ...


class QXmlResultItems(Shiboken.Object):

    def __init__(self) -> None: ...


class QXmlSchema(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtXmlPatterns.QXmlSchema) -> None: ...


class QXmlSchemaValidator(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, schema: PySide2.QtXmlPatterns.QXmlSchema) -> None: ...


class QXmlSerializer(PySide2.QtXmlPatterns.QAbstractXmlReceiver):

    def __init__(self, query: PySide2.QtXmlPatterns.QXmlQuery, outputDevice: PySide2.QtCore.QIODevice) -> None: ...


# eof



#############################################################################
##
## Copyright (C) 2022 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of Qt for Python.
##
## $QT_BEGIN_LICENSE:COMM$
##
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## $QT_END_LICENSE$
##
#############################################################################

from __future__ import annotations

"""
This file contains the exact signatures for all functions in module
Shiboken, except for defaults which are replaced by "...".
"""

# Module `Shiboken`

from shiboken2 import Shiboken


class Object(object):

    def __init__(self) -> None: ...


class VoidPtr(object): ...


def _unpickle_enum(arg__1: object, arg__2: object) -> object: ...
def createdByPython(arg__1: Shiboken.Object) -> bool: ...
def delete(arg__1: Shiboken.Object) -> None: ...
def dump(arg__1: object) -> str: ...
def getAllValidWrappers() -> Shiboken.Object: ...
def getCppPointer(arg__1: Shiboken.Object) -> Shiboken.Object: ...
def invalidate(arg__1: Shiboken.Object) -> None: ...
def isValid(arg__1: object) -> bool: ...
def ownedByPython(arg__1: Shiboken.Object) -> bool: ...
def wrapInstance(arg__1: int, arg__2: type) -> Shiboken.Object: ...


# eof



#############################################################################
##
## Copyright (C) 2020 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of Qt for Python.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 3 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL3 included in the
## packaging of this file. Please review the following information to
## ensure the GNU Lesser General Public License version 3 requirements
## will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 2.0 or (at your option) the GNU General
## Public license version 3 or any later version approved by the KDE Free
## Qt Foundation. The licenses are as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-2.0.html and
## https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################
from __future__ import annotations

"""
This file contains the exact signatures for all functions in module
PySide2.QtRemoteObjects, except for defaults which are replaced by "...".
"""

# Module PySide2.QtRemoteObjects
import PySide2
try:
    import typing
except ImportError:
    from PySide2.support.signature import typing
from PySide2.support.signature.mapping import (
    Virtual, Missing, Invalid, Default, Instance)

from shiboken2 import Shiboken

import PySide2.QtCore
import PySide2.QtRemoteObjects


class QAbstractItemModelReplica(PySide2.QtCore.QAbstractItemModel): ...


class QRemoteObjectAbstractPersistedStore(PySide2.QtCore.QObject):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...


class QRemoteObjectDynamicReplica(PySide2.QtRemoteObjects.QRemoteObjectReplica): ...


class QRemoteObjectHost(PySide2.QtRemoteObjects.QRemoteObjectHostBase):

    @typing.overload
    def __init__(self, address: PySide2.QtCore.QUrl, parent: PySide2.QtCore.QObject) -> None: ...
    @typing.overload
    def __init__(self, address: PySide2.QtCore.QUrl, registryAddress: PySide2.QtCore.QUrl = ..., allowedSchemas: PySide2.QtRemoteObjects.QRemoteObjectHostBase.AllowedSchemas = ..., parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...


class QRemoteObjectHostBase(PySide2.QtRemoteObjects.QRemoteObjectNode):
    BuiltInSchemasOnly       : QRemoteObjectHostBase.AllowedSchemas = ... # 0x0
    AllowExternalRegistration: QRemoteObjectHostBase.AllowedSchemas = ... # 0x1

    class AllowedSchemas(Shiboken.Enum):
        BuiltInSchemasOnly       : QRemoteObjectHostBase.AllowedSchemas = ... # 0x0
        AllowExternalRegistration: QRemoteObjectHostBase.AllowedSchemas = ... # 0x1


class QRemoteObjectNode(PySide2.QtCore.QObject):
    NoError                  : QRemoteObjectNode.ErrorCode = ... # 0x0
    RegistryNotAcquired      : QRemoteObjectNode.ErrorCode = ... # 0x1
    RegistryAlreadyHosted    : QRemoteObjectNode.ErrorCode = ... # 0x2
    NodeIsNoServer           : QRemoteObjectNode.ErrorCode = ... # 0x3
    ServerAlreadyCreated     : QRemoteObjectNode.ErrorCode = ... # 0x4
    UnintendedRegistryHosting: QRemoteObjectNode.ErrorCode = ... # 0x5
    OperationNotValidOnClientNode: QRemoteObjectNode.ErrorCode = ... # 0x6
    SourceNotRegistered      : QRemoteObjectNode.ErrorCode = ... # 0x7
    MissingObjectName        : QRemoteObjectNode.ErrorCode = ... # 0x8
    HostUrlInvalid           : QRemoteObjectNode.ErrorCode = ... # 0x9
    ProtocolMismatch         : QRemoteObjectNode.ErrorCode = ... # 0xa
    ListenFailed             : QRemoteObjectNode.ErrorCode = ... # 0xb

    class ErrorCode(Shiboken.Enum):
        NoError                  : QRemoteObjectNode.ErrorCode = ... # 0x0
        RegistryNotAcquired      : QRemoteObjectNode.ErrorCode = ... # 0x1
        RegistryAlreadyHosted    : QRemoteObjectNode.ErrorCode = ... # 0x2
        NodeIsNoServer           : QRemoteObjectNode.ErrorCode = ... # 0x3
        ServerAlreadyCreated     : QRemoteObjectNode.ErrorCode = ... # 0x4
        UnintendedRegistryHosting: QRemoteObjectNode.ErrorCode = ... # 0x5
        OperationNotValidOnClientNode: QRemoteObjectNode.ErrorCode = ... # 0x6
        SourceNotRegistered      : QRemoteObjectNode.ErrorCode = ... # 0x7
        MissingObjectName        : QRemoteObjectNode.ErrorCode = ... # 0x8
        HostUrlInvalid           : QRemoteObjectNode.ErrorCode = ... # 0x9
        ProtocolMismatch         : QRemoteObjectNode.ErrorCode = ... # 0xa
        ListenFailed             : QRemoteObjectNode.ErrorCode = ... # 0xb

    @typing.overload
    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...
    @typing.overload
    def __init__(self, registryAddress: PySide2.QtCore.QUrl, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...


class QRemoteObjectPendingCall(Shiboken.Object):
    NoError                  : QRemoteObjectPendingCall.Error = ... # 0x0
    InvalidMessage           : QRemoteObjectPendingCall.Error = ... # 0x1

    class Error(Shiboken.Enum):
        NoError                  : QRemoteObjectPendingCall.Error = ... # 0x0
        InvalidMessage           : QRemoteObjectPendingCall.Error = ... # 0x1

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: PySide2.QtRemoteObjects.QRemoteObjectPendingCall) -> None: ...


class QRemoteObjectPendingCallWatcher(PySide2.QtCore.QObject, PySide2.QtRemoteObjects.QRemoteObjectPendingCall):

    def __init__(self, call: PySide2.QtRemoteObjects.QRemoteObjectPendingCall, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...


class QRemoteObjectRegistry(PySide2.QtRemoteObjects.QRemoteObjectReplica): ...


class QRemoteObjectRegistryHost(PySide2.QtRemoteObjects.QRemoteObjectHostBase):

    def __init__(self, registryAddress: PySide2.QtCore.QUrl = ..., parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...


class QRemoteObjectReplica(PySide2.QtCore.QObject):
    Uninitialized            : QRemoteObjectReplica.State = ... # 0x0
    Default                  : QRemoteObjectReplica.State = ... # 0x1
    Valid                    : QRemoteObjectReplica.State = ... # 0x2
    Suspect                  : QRemoteObjectReplica.State = ... # 0x3
    SignatureMismatch        : QRemoteObjectReplica.State = ... # 0x4

    class State(Shiboken.Enum):
        Uninitialized            : QRemoteObjectReplica.State = ... # 0x0
        Default                  : QRemoteObjectReplica.State = ... # 0x1
        Valid                    : QRemoteObjectReplica.State = ... # 0x2
        Suspect                  : QRemoteObjectReplica.State = ... # 0x3
        SignatureMismatch        : QRemoteObjectReplica.State = ... # 0x4

    def __init__(self) -> None: ...


class QRemoteObjectSettingsStore(PySide2.QtRemoteObjects.QRemoteObjectAbstractPersistedStore):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...) -> None: ...


class QRemoteObjectSourceLocationInfo(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, QRemoteObjectSourceLocationInfo: PySide2.QtRemoteObjects.QRemoteObjectSourceLocationInfo) -> None: ...
    @typing.overload
    def __init__(self, typeName_: str, hostUrl_: PySide2.QtCore.QUrl) -> None: ...


# eof



from __future__ import print_function
import os
import sys
from textwrap import dedent

__all__ = list("Qt" + body for body in
    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;X11Extras;Xml;XmlPatterns;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLFunctions;RemoteObjects;SerialPort;Svg;UiTools"
    .split(";"))
__version__ = "5.15.12"
__version_info__ = (5, 15, 12, "", "")


def _additional_dll_directories(package_dir):
    # Find shiboken2 relative to the package directory.
    root = os.path.dirname(package_dir)
    # Check for a flat .zip as deployed by cx_free(PYSIDE-1257)
    if root.endswith('.zip'):
        return []
    shiboken2 = os.path.join(root, 'shiboken2')
    if os.path.isdir(shiboken2): # Standard case, only shiboken2 is needed
        return [shiboken2]
    # The below code is for the build process when generate_pyi.py
    # is executed in the build directory. We need libpyside and Qt in addition.
    shiboken2 = os.path.join(os.path.dirname(root), 'shiboken2', 'libshiboken')
    if not os.path.isdir(shiboken2):
        raise ImportError(shiboken2 + ' does not exist')
    result = [shiboken2, os.path.join(root, 'libpyside')]
    for path in os.environ.get('PATH').split(';'):
        if path:
             if os.path.exists(os.path.join(path, 'qmake.exe')):
                 result.append(path)
                 break
    return result


def _setupQtDirectories():
    # On Windows we need to explicitly import the shiboken2 module so
    # that the libshiboken.dll dependency is loaded by the time a
    # Qt module is imported. Otherwise due to PATH not containing
    # the shiboken2 module path, the Qt module import would fail
    # due to the missing libshiboken dll.
    # In addition, as of Python 3.8, the shiboken package directory
    # must be added to the DLL search paths so that shiboken2.dll
    # is found.
    # We need to do the same on Linux and macOS, because we do not
    # embed rpaths into the PySide2 libraries that would point to
    # the libshiboken library location. Importing the module
    # loads the libraries into the process memory beforehand, and
    # thus takes care of it for us.

    pyside_package_dir = os.path.abspath(os.path.dirname(__file__))

    if sys.platform == 'win32' and sys.version_info[0] == 3 and sys.version_info[1] >= 8:
        for dir in _additional_dll_directories(pyside_package_dir):
            os.add_dll_directory(dir)

    try:
        import shiboken2
    except Exception:
        paths = ', '.join(sys.path)
        print('PySide2/__init__.py: Unable to import shiboken2 from {}'.format(paths),
              file=sys.stderr)
        raise

    #   Trigger signature initialization.
    try:
        # PYSIDE-829: Avoid non-existent attributes in compiled code (Nuitka).
        # We now use an explicit function instead of touching a signature.
        _init_pyside_extension()
    except AttributeError:
        print(dedent('''\
            {stars}
            PySide2/__init__.py: The `signature` module was not initialized.
            This libshiboken module was loaded from

            "{shiboken2.__file__}".

            Please make sure that this is the real shiboken2 binary and not just a folder.
            {stars}
            ''').format(stars=79*"*", **locals()), file=sys.stderr)
        raise

    if sys.platform == 'win32':
        # PATH has to contain the package directory, otherwise plugins
        # won't be able to find their required Qt libraries (e.g. the
        # svg image plugin won't find Qt5Svg.dll).
        os.environ['PATH'] = pyside_package_dir + os.pathsep + os.environ['PATH']

        # On Windows, add the PySide2\openssl folder (created by setup.py's
        # --openssl option) to the PATH so that the SSL DLLs can be found
        # when Qt tries to dynamically load them. Tell Qt to load them and
        # then reset the PATH.
        openssl_dir = os.path.join(pyside_package_dir, 'openssl')
        if os.path.exists(openssl_dir):
            path = os.environ['PATH']
            try:
                os.environ['PATH'] = openssl_dir + os.pathsep + path
                try:
                    from . import QtNetwork
                except ImportError:
                    pass
                else:
                    QtNetwork.QSslSocket.supportsSsl()
            finally:
                os.environ['PATH'] = path

_setupQtDirectories()



"""
This module is here to ensure compatibility of Windows/Linux/MacOS and
different Python versions.
"""
import errno
import sys
import pickle
from typing import Any


class Unpickler(pickle.Unpickler):
    def find_class(self, module: str, name: str) -> Any:
        # Python 3.13 moved pathlib implementation out of __init__.py as part of
        # generalising its implementation. Ensure that we support loading
        # pickles from 3.13 on older version of Python. Since 3.13 maintained a
        # compatible API, pickles from older Python work natively on the newer
        # version.
        if module == 'pathlib._local':
            module = 'pathlib'
        return super().find_class(module, name)


def pickle_load(file):
    try:
        return Unpickler(file).load()
    # Python on Windows don't throw EOF errors for pipes. So reraise them with
    # the correct type, which is caught upwards.
    except OSError:
        if sys.platform == 'win32':
            raise EOFError()
        raise


def pickle_dump(data, file, protocol):
    try:
        pickle.dump(data, file, protocol)
        # On Python 3.3 flush throws sometimes an error even though the writing
        # operation should be completed.
        file.flush()
    # Python on Windows don't throw EPIPE errors for pipes. So reraise them with
    # the correct type and error number.
    except OSError:
        if sys.platform == 'win32':
            raise IOError(errno.EPIPE, "Broken pipe")
        raise



import sys
from typing import List, Optional, Sequence, Tuple, Union, overload

from _tracemalloc import *

def get_object_traceback(obj: object) -> Optional[Traceback]: ...
def take_snapshot() -> Snapshot: ...

class DomainFilter:
    inclusive: bool
    domain: int
    def __init__(self, inclusive: bool, domain: int) -> None: ...

class Filter:
    domain: Optional[int]
    inclusive: bool
    lineno: Optional[int]
    filename_pattern: str
    all_frames: bool
    def __init__(
        self,
        inclusive: bool,
        filename_pattern: str,
        lineno: Optional[int] = ...,
        all_frames: bool = ...,
        domain: Optional[int] = ...,
    ) -> None: ...

class Statistic:
    count: int
    size: int
    traceback: Traceback
    def __init__(self, traceback: Traceback, size: int, count: int) -> None: ...

class StatisticDiff:
    count: int
    count_diff: int
    size: int
    size_diff: int
    traceback: Traceback
    def __init__(self, traceback: Traceback, size: int, size_diff: int, count: int, count_diff: int) -> None: ...

_FrameTupleT = Tuple[str, int]

class Frame:
    filename: str
    lineno: int
    def __init__(self, frame: _FrameTupleT) -> None: ...

if sys.version_info >= (3, 9):
    _TraceTupleT = Union[Tuple[int, int, Sequence[_FrameTupleT], Optional[int]], Tuple[int, int, Sequence[_FrameTupleT]]]
else:
    _TraceTupleT = Tuple[int, int, Sequence[_FrameTupleT]]

class Trace:
    domain: int
    size: int
    traceback: Traceback
    def __init__(self, trace: _TraceTupleT) -> None: ...

class Traceback(Sequence[Frame]):
    if sys.version_info >= (3, 9):
        total_nframe: Optional[int]
        def __init__(self, frames: Sequence[_FrameTupleT], total_nframe: Optional[int] = ...) -> None: ...
    else:
        def __init__(self, frames: Sequence[_FrameTupleT]) -> None: ...
    if sys.version_info >= (3, 7):
        def format(self, limit: Optional[int] = ..., most_recent_first: bool = ...) -> List[str]: ...
    else:
        def format(self, limit: Optional[int] = ...) -> List[str]: ...
    @overload
    def __getitem__(self, i: int) -> Frame: ...
    @overload
    def __getitem__(self, s: slice) -> Sequence[Frame]: ...
    def __len__(self) -> int: ...

class Snapshot:
    def __init__(self, traces: Sequence[_TraceTupleT], traceback_limit: int) -> None: ...
    def compare_to(self, old_snapshot: Snapshot, key_type: str, cumulative: bool = ...) -> List[StatisticDiff]: ...
    def dump(self, filename: str) -> None: ...
    def filter_traces(self, filters: Sequence[Union[DomainFilter, Filter]]) -> Snapshot: ...
    @staticmethod
    def load(filename: str) -> Snapshot: ...
    def statistics(self, key_type: str, cumulative: bool = ...) -> List[Statistic]: ...
    traceback_limit: int
    traces: Sequence[Trace]
